@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11199 2018-08-11 16:11:45Z Lavender $
+# $Id: __init__.py 11232 2018-09-26 20:01:18Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-08-12 01:11:45 +0900 (週日, 12 八月 2018) $
-# $Revision: 11199 $
+# $Date: 2018-09-27 05:01:18 +0900 (週四, 27 九月 2018) $
+# $Revision: 11232 $
 
 from django.conf import settings as _settings
 from django.utils.translation import ugettext_lazy as _
@@ -22,13 +22,24 @@ class settings(object):
     ZEPHYRUS_BLOG_MAYLIKE_DEFAULT_TEMPLATE = \
         "blog_extension/Default.html"
 
+    ZEPHYRUS_BLOG_DATE_DEFAULT_TEMPLATE = \
+        "blog_extension/Date.html"
+
     ZEPHYRUS_BLOG_MAYLIKE_TEMPLATES = [
         (ZEPHYRUS_BLOG_MAYLIKE_DEFAULT_TEMPLATE, _("Default")),
     ]
+    ZEPHYRUS_BLOG_DATE_TEMPLATES = [
+        (ZEPHYRUS_BLOG_DATE_DEFAULT_TEMPLATE, _("Default")),
+    ]
 
     if hasattr(_settings, 'ZEPHYRUS_BLOG_MAYLIKE_TEMPLATES'):
         for ele in _settings.ZEPHYRUS_BLOG_MAYLIKE_TEMPLATES:
             if not ele[0] == ZEPHYRUS_BLOG_MAYLIKE_DEFAULT_TEMPLATE:
                 ZEPHYRUS_BLOG_MAYLIKE_TEMPLATES.append(ele)
 
+    if hasattr(_settings, 'ZEPHYRUS_BLOG_DATE_TEMPLATES'):
+        for ele in _settings.ZEPHYRUS_BLOG_DATE_TEMPLATES:
+            if not ele[0] == ZEPHYRUS_BLOG_MAYLIKE_DEFAULT_TEMPLATE:
+                ZEPHYRUS_BLOG_DATE_TEMPLATES.append(ele)
+
 
