@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11376 2019-03-03 14:21:00Z Lavender $
+# $Id: __init__.py 11436 2019-04-10 17:56:15Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,16 +12,21 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-03-03 23:21:00 +0900 (週日, 03 三月 2019) $
-# $Revision: 11376 $
+# $Date: 2019-04-11 02:56:15 +0900 (週四, 11 四月 2019) $
+# $Revision: 11436 $
 
 import os
 import logging
 import platform
 import six
 
+import django
+
 from django.conf import settings
 
+DJANGO_VERSION = (django.VERSION[0] * 100 + django.VERSION[1] * 10 +
+                  django.VERSION[2])
+
 ROOT_DIR_PATH = os.path.abspath(
     os.path.join('.'))
 
