@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 11414 2019-03-30 06:35:59Z Lavender $
+# $Id: cms_dumpdata.py 11436 2019-04-10 17:56:15Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-03-30 15:35:59 +0900 (週六, 30 三月 2019) $
-# $Revision: 11414 $
+# $Date: 2019-04-11 02:56:15 +0900 (週四, 11 四月 2019) $
+# $Revision: 11436 $
 
 import os
 import sys
@@ -27,9 +27,15 @@ else:
 
 from django.core.management.base import BaseCommand
 from django.core import serializers
-from django.db.models import get_app, get_models
 from django.db.models.query import QuerySet
 
+from Zephyrus.boilerplate.management.commands import DJANGO_VERSION
+
+if DJANGO_VERSION >= 210: # django >= 1.11
+    from django.apps import apps
+else:
+    from django.db.models import get_app, get_models
+
 class Command(BaseCommand):
 
     help = 'Dump all data include filer.File to initial_data.json'
@@ -42,9 +48,12 @@ class Command(BaseCommand):
             help="No export auth data.")
     
     def handle(self, *args, **options):
-        app = get_app('filer')
-        
-        modelList = get_models(app)
+        if DJANGO_VERSION >= 210:
+            app = apps.get_app_config('filer')
+            modelList = [apps.get_model('filer', m) for m in app.models]
+        else:
+            app = get_app('filer')        
+            modelList = get_models(app)
         
         dataStream = StringIO()
         
@@ -54,15 +63,20 @@ class Command(BaseCommand):
                 for obj in model.objects.iterator():
                     yield obj
                     
-        
-        serializers.serialize(
-            'json', getObjects(), indent=2, 
-            use_natural_keys=True, stream=dataStream)
+        if DJANGO_VERSION >= 210:
+            serializers.serialize(
+                'json', getObjects(), indent=2, 
+                use_natural_foreign_keys=True, use_natural_primary_keys=True, 
+                stream=dataStream)
+        else:
+            serializers.serialize(
+                'json', getObjects(), indent=2, 
+                    use_natural_keys=True, stream=dataStream)
                 
         filerData = json.loads(dataStream.getvalue())
         
         os.system(
-            "%s manage.py dumpdata auth > authData.json" %  
+            "%s manage.py dumpdata -e auth.Permission auth > authData.json" %  
             sys.executable)
 
         os.system(
@@ -71,7 +85,8 @@ class Command(BaseCommand):
             
         os.system(
             ("%s manage.py dumpdata "
-             "-e auth -e filer -e contenttypes -e cms.Treenode "
+             "-e auth -e sites -e filer -e "
+             "contenttypes -e cms.Treenode"
              "> otherData.json") % 
              sys.executable)
         
