@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 11376 2019-03-03 14:21:00Z Lavender $
+# $Id: pluginize.py 11436 2019-04-10 17:56:15Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-03-03 23:21:00 +0900 (週日, 03 三月 2019) $
-# $Revision: 11376 $
+# $Date: 2019-04-11 02:56:15 +0900 (週四, 11 四月 2019) $
+# $Revision: 11436 $
 
 import os
 import json
@@ -44,7 +44,8 @@ from html5lib import sanitizer
 from html5lib.filters import sanitizer as filtersSanitizer
 
 from Zephyrus.boilerplate.management.commands import (
-    TEMPLATES_DIR_PATH, STATIC_DIR_PATH, FIXTURES_DIR_PATH, ROOT_DIR_PATH)
+    TEMPLATES_DIR_PATH, STATIC_DIR_PATH, 
+    FIXTURES_DIR_PATH, ROOT_DIR_PATH, DJANGO_VERSION)
 from Zephyrus.boilerplate.management.commands import (
     createLogger, CSS_PROPERTIES, toBytes)
 from Zephyrus.boilerplate.management.commands import open3 as open
@@ -222,7 +223,7 @@ class Placeholder2(Placeholder):
                         hashlib.md5(
                             toBytes(placeholder.slot)).hexdigest(), attrList))
                     
-                    if cms.__version__.startswith('3.5'):
+                    if not cms.__version__.startswith('3.4'):
                         if root.tag == 'a':
                             link = root.get('href')
                             if link == '' or link == None:
@@ -373,11 +374,16 @@ class Command(BaseCommand):
                 f.write(content)
 
             # build CMSContext.js
-            if not cms.__version__.startswith('3.5'):
+            if cms.__version__.startswith('3.4'):
                 temp = get_template('boilerplate/js/CMSContext.js')
-                replaceStr = Context({
-                    'tagList': newTagList, 
-                })
+                if DJANGO_VERSION >= 210: # django >= 1.11
+                    replaceStr = {
+                        'tagList': newTagList, 
+                    }
+                else:
+                    replaceStr = Context({
+                        'tagList': newTagList, 
+                    })
                 content = temp.render(replaceStr)
                 with open(contextPath, 'w') as f:
                     f.write(content)
