@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 11391 2019-03-21 07:46:45Z Lavender $
+# $Id: setup.py 11436 2019-04-10 17:56:15Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,12 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-03-21 16:46:45 +0900 (週四, 21 三月 2019) $
-# $Revision: 11391 $
+# $Date: 2019-04-11 02:56:15 +0900 (週四, 11 四月 2019) $
+# $Revision: 11436 $
 
 import os
 import sys
+import time
 import logging
 import shutil
 import json
@@ -223,7 +224,7 @@ else:
                 yesOrNo = 'yes'
                 
             if yesOrNo == 'yes':
-                if not cms.__version__.startswith('3.5'):
+                if cms.__version__.startswith('3.4'):
                     if canAddPlugin(
                         'djangocms-file', 'djangocms_file==2.0.2'):
                         pluginList.append('djangocms_file')
@@ -310,6 +311,8 @@ if __name__ == "__main__":
         wizard = args.wizard
         mode = 'user'
         
+        timeLocal = time.strftime("%z", time.gmtime())
+        
         if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
             with open(os.path.join(SETUP_DIR, 'MANIFAST.INFO')) as f:
                 data = json.loads(f.read())
@@ -322,13 +325,15 @@ if __name__ == "__main__":
             installVersion = "0.9.7"
         elif cmsVersion.startswith("3.5"):
             installVersion = "1.0.0"
+        elif cmsVersion.startswith("3.6"):
+            installVersion = "1.1.0"
         else:
             installVersion = "1.0.0"
            
         path = args.path
        
         settingsPath = findSettings(path)
-       
+        
         createProject = False
        
         if not settingsPath:
@@ -358,11 +363,16 @@ if __name__ == "__main__":
             path = os.path.join(path, projectName)
            
             if wizard:
-                result = os.system(
-                    "djangocms -f -p \"%s\" \"%s\" -w" % (path, projectName))
+                command = "djangocms -f -p \"%s\" \"%s\" -w" % (
+                    path, projectName)
             else:
-                result = os.system(
-                    "djangocms -f -p \"%s\" \"%s\"" % (path, projectName))
+                command = "djangocms -f -p \"%s\" \"%s\"" % (
+                    path, projectName)
+                    
+            if timeLocal in ["+0800",]:
+                command = "%s --languages=zh-hant" % command
+                
+            result = os.system(command)
            
             createProject = True
                
